==> haskell-http-conduit-2.3.9.1-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-7yUhFyD6XygFKbmlHvKljz
key:                  http-conduit-2.3.9.1-7yUhFyD6XygFKbmlHvKljz
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  064cf666f7a0e38fb0835ced88fd7e82
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-7yUhFyD6XygFKbmlHvKljz
depends:
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp
    attoparsec-0.14.4-AaLxHw66o7ZDAbKIqXiED8
    attoparsec-aeson-2.1.0.0-4Nv8ys85dGe1f7c696SXRA base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-4zipxoOtaf58vXmKwQLSFK
    conduit-extra-1.3.8-CuMCo9UX0Yv2h7Df5xkGn7
    http-client-0.7.19-3rmvGvyaabxFxCJ9oJ0aDx
    http-client-tls-0.3.6.4-8TCMitZJevE8PRVlviJUoX
    http-types-0.12.4-AxSTuELtXS8Ebx20Rd9Bgd mtl-2.2.2
    resourcet-1.2.6-6OalXqf73l86eTJ5NzIFB9 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.9.1-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-conduit
version:              2.3.9.1
visibility:           public
id:                   http-conduit-2.3.9.1-IBKu1TrmJP6Kq88yCkjWcg
key:                  http-conduit-2.3.9.1-IBKu1TrmJP6Kq88yCkjWcg
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/http-client
synopsis:
    HTTP client package with conduit interface and HTTPS support.

description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.

category:             Web, Conduit
abi:                  6db9a4c44b9230d1fe68a71eb0036646
exposed:              True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-conduit-2.3.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-conduit
hs-libraries:         HShttp-conduit-2.3.9.1-IBKu1TrmJP6Kq88yCkjWcg
depends:
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB
    attoparsec-0.14.4-Kqu9azGoeFY4BlHGbH5HBg
    attoparsec-aeson-2.1.0.0-JsBET69fmF1ANsaFWAYuXC base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-LSEd28HkJLcLIWho4Hpdv5
    conduit-extra-1.3.8-1LAIQLfxuR7D84QyyD6SR3
    http-client-0.7.19-2IAKaL0RajRLDWsZpaLmo9
    http-client-tls-0.3.6.4-2Fy9IJdNZPjACQ4RZSV8Nh
    http-types-0.12.4-JKUCrzdlATTa7w8tKVNt1 mtl-2.2.2
    resourcet-1.2.6-7iKUUdP710zAH2Mxgc0pA5 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:
    /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock

haddock-html:         /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
